@@ -285,6 +285,7 @@ cal_shell_view_update_actions (EShellView *shell_view)
 	gboolean selection_can_delegate;
 	gboolean single_event_selected;
 	gboolean refresh_supported;
+	gboolean all_sources_selected;
 
 	/* Chain up to parent's update_actions() method. */
 	E_SHELL_VIEW_CLASS (e_cal_shell_view_parent_class)->
@@ -347,9 +348,15 @@ cal_shell_view_update_actions (EShellView *shell_view)
 		(state & E_CAL_BASE_SHELL_SIDEBAR_PRIMARY_SOURCE_IN_COLLECTION);
 	refresh_supported =
 		(state & E_CAL_BASE_SHELL_SIDEBAR_SOURCE_SUPPORTS_REFRESH);
+	all_sources_selected =
+		(state & E_CAL_BASE_SHELL_SIDEBAR_ALL_SOURCES_SELECTED) != 0;
 
 	any_events_selected = (single_event_selected || multiple_events_selected);
 
+	action = ACTION (CALENDAR_SELECT_ALL);
+	sensitive = !all_sources_selected;
+	gtk_action_set_sensitive (action, sensitive);
+
 	action = ACTION (CALENDAR_COPY);
 	sensitive = has_primary_source;
 	gtk_action_set_sensitive (action, sensitive);
@@ -534,6 +541,8 @@ cal_shell_view_constructed (GObject *object)
 	container = e_shell_searchbar_get_search_box (searchbar);
 
 	widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_style_context_add_class (
+		gtk_widget_get_style_context (widget), "linked");
 	cal_shell_view_add_action_button (
 		GTK_BOX (widget), ACTION (CALENDAR_SEARCH_PREV));
 	cal_shell_view_add_action_button (
